@@ -1,14 +1,11 @@
 <?php
 
-/**
- * These two files are needed to support php < 7.1.
- * In modern versions of phpunit (after php 7.1 was released), signature of phpunit's setUp() and tearDown() methods changed.
- * Until PhpAmqpLib supports php <7.1, these files are needed to make tests work on old php versions
- */
-
 namespace PhpAmqpLib\Tests;
 
-class TestCaseCompat extends \PHPUnit\Framework\TestCase
+use PHPUnit\Framework\TestCase;
+use PHPUnit\Runner\Version;
+
+class TestCaseCompat extends TestCase
 {
     /**
      * This method should be used instead of default phpunit's setUp for compatibility with several phpunit versions
@@ -27,10 +24,20 @@ class TestCaseCompat extends \PHPUnit\Framework\TestCase
     }
 
     protected function setUp(): void {
-        static::setUpCompat();
+        $this->setUpCompat();
     }
 
     protected function tearDown(): void {
-        static::tearDownCompat();
+        $this->tearDownCompat();
+    }
+
+    public static function assertPattern(string $pattern, string $string, string $message = ''): void
+    {
+        $series = Version::series();
+        if (version_compare($series, '9.5') >= 0) {
+            self::assertMatchesRegularExpression($pattern, $string, $message);
+        } else {
+            self::assertRegExp($pattern, $string, $message);
+        }
     }
 }
